Struct tract_tensorflow::prelude::OutletId [−]
Identifier for a node output in the graph.
This happens to be a unique identifier of any variable tensor in the graph (as the graph typically connect one single node output to one or several inputs slots)
Fields
node: usizenode identifier in the graph
slot: usizerank of the input in the node
Implementations
impl OutletId