State

Trait State 

pub trait State:
    Any
    + Downcast
    + Debug
    + 'static {
    // Required methods
    fn run(
        &mut self,
        inputs: SmallVec<[TValue; 4]>,
    ) -> Result<SmallVec<[TValue; 4]>, Error>;
    fn runnable(&self) -> &(dyn Runnable + 'static);
    fn initializable_states_count(&self) -> usize;
    fn get_states_facts(&self) -> Vec<TypedFact>;
    fn init_state(&mut self, states: &[TValue]) -> Result<(), Error>;
    fn get_states(&self) -> Result<Vec<TValue>, Error>;
    fn freeze(&self) -> Box<dyn FrozenState>;

    // Provided methods
    fn input_count(&self) -> usize { ... }
    fn output_count(&self) -> usize { ... }
}

Required Methods

fn run( &mut self, inputs: SmallVec<[TValue; 4]>, ) -> Result<SmallVec<[TValue; 4]>, Error>

fn runnable(&self) -> &(dyn Runnable + 'static)

fn initializable_states_count(&self) -> usize

fn get_states_facts(&self) -> Vec<TypedFact>

fn init_state(&mut self, states: &[TValue]) -> Result<(), Error>

fn get_states(&self) -> Result<Vec<TValue>, Error>

fn freeze(&self) -> Box<dyn FrozenState>

Provided Methods

Implementations

Source

impl dyn State

pub fn is<__T>(&self) -> bool
where __T: State,

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T>(self: Box<dyn State>) -> Result<Box<__T>, Box<dyn State>>
where __T: State,

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T>(self: Rc<dyn State>) -> Result<Rc<__T>, Rc<dyn State>>
where __T: State,

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T>(&self) -> Option<&__T>
where __T: State,

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T>(&mut self) -> Option<&mut __T>
where __T: State,

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.

Implementors