#[repr(i32)]pub enum VariableAggregation {
None = 0,
Sum = 1,
Mean = 2,
OnlyFirstReplica = 3,
}Expand description
Indicates how a distributed variable will be aggregated.
Variants
None = 0
NONE: This is the default, giving an error if you use a
variable-update operation with multiple replicas.
Sum = 1
SUM: Add the updates across replicas.
Mean = 2
MEAN: Take the arithmetic mean (“average”) of the updates across
replicas.
OnlyFirstReplica = 3
ONLY_FIRST_REPLICA: This is for when every replica is performing the same
update, but we only want to perform the update once. Used, e.g., for the
global step counter.
Implementations
Sourceimpl VariableAggregation
impl VariableAggregation
Sourcepub fn from_i32(value: i32) -> Option<VariableAggregation>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<VariableAggregation>
Use the TryFrom<i32> implementation instead
Converts an i32 to a VariableAggregation, or None if value is not a valid variant.
Sourceimpl VariableAggregation
impl VariableAggregation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.