Struct tract_tensorflow::tfpb::tensorflow::meta_graph_def::MetaInfoDef [−][src]
Meta information regarding the graph to be exported. To be used by users of this protocol buffer to encode information regarding their meta graph.
Fields
meta_graph_version: StringUser specified Version string. Can be the name of the model and revision, steps this model has been trained to, etc.
stripped_op_list: Option<OpList>A copy of the OpDefs used by the producer of this graph_def. Descriptions and Ops not used in graph_def are stripped out.
any_info: Option<Any>A serialized protobuf. Can be the time this meta graph is created, or modified, or name of the model.
User supplied tag(s) on the meta_graph and included graph_def.
MetaGraphDefs should be tagged with their capabilities or use-cases. Examples: “train”, “serve”, “gpu”, “tpu”, etc. These tags enable loaders to access the MetaGraph(s) appropriate for a specific use-case or runtime environment.
tensorflow_version: StringThe version string of the tensorflow build used to write this graph. This will be populated by the framework, which will overwrite any user supplied value.
tensorflow_git_version: StringThe git_version string of the tensorflow build used to write this graph. This will be populated by the framework, which will overwrite any user supplied value.
stripped_default_attrs: boolA flag to denote whether default-valued attrs have been stripped from the nodes in this graph_def.