#[repr(i32)]pub enum CheckpointFormatVersion {
Legacy = 0,
V1 = 1,
V2 = 2,
}Expand description
A version number that identifies a different on-disk checkpoint format. Usually, each subclass of BaseSaverBuilder works with a particular version/format. However, it is possible that the same builder may be upgraded to support a newer checkpoint format in the future.
Variants
Legacy = 0
Internal legacy format.
V1 = 1
Deprecated format: tf.Saver() which works with tensorflow::table::Table.
V2 = 2
Current format: more efficient.
Implementations
Sourceimpl CheckpointFormatVersion
impl CheckpointFormatVersion
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of CheckpointFormatVersion.
Sourcepub fn from_i32(value: i32) -> Option<CheckpointFormatVersion>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CheckpointFormatVersion>
Use the TryFrom<i32> implementation instead
Converts an i32 to a CheckpointFormatVersion, or None if value is not a valid variant.
Sourceimpl CheckpointFormatVersion
impl CheckpointFormatVersion
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.